@@ -1,8 +1,9 @@
 #include <Rcpp.h>
+#include<math.h>
 using namespace Rcpp;
 // [[Rcpp::export]]
-NumericVector GoFNS(double t, double n,double m) { 
-  std::vector<double> res(m,0);  
+NumericVector GoFNS(double t, double n,double m) {
+  NumericVector res(m);
   double p_r,q_r,Q_r,d_Q_r = 0;
   double d2_Q_r, d3_Q_r,d4_Q_r=0;
   for(int i=0 ; i<m; ++i){
@@ -18,4 +19,4 @@ NumericVector GoFNS(double t, double n,double m) {
    res[i] += q_r*p_r/((n+2)*(n+2))*(1/3*(q_r - p_r)*d3_Q_r + 1/8*p_r*q_r*d4_Q_r);
 }
 NumericVector temp=Rcpp::wrap(res);
-return temp;}
+return res;}
