@@ -5,8 +5,11 @@ NumericVector GoFsim(int nsim, int n, Function fun) {
   NumericVector res(nsim);
   NumericVector V(n);
   for(int i=0;i<nsim;i++){
+    GetRNGstate();
     V =-log(runif(n));
+    PutRNGstate();
     res[i]=as<double>(fun(V));
+
   }
  // NumericVector temp=wrap(res);
   std::sort(res.begin(),res.end());
